import { API } from "aws-amplify";
import { FetchBaseQueryError } from "@reduxjs/toolkit/dist/query/fetchBaseQuery";
import { apiName, resourcePath } from "../../../constants";
import { ContactEntry, UnsavedContactEntry } from "types";

export async function getAllContacts(
  jwtToken: string
): Promise<{ data: ContactEntry[] } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.get(apiName, `${resourcePath}`, {
      headers: {
        Authorization: `Bearer ${jwtToken}`,
      },
    });

    return { data };
  } catch (error) {
    console.error("API Error:", error);

    return {
      error: error as FetchBaseQueryError,
    };
  }
}

export async function getContactById(
  contactId: string,
  jwtToken: string
): Promise<{ data: ContactEntry } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.get(apiName, `${resourcePath}?id=${contactId}`, {
      headers: {
        Authorization: `Bearer ${jwtToken}`,
      },
    });

    return { data };
  } catch (error) {
    console.error("API Error:", error);

    return {
      error: error as FetchBaseQueryError,
    };
  }
}

export async function createContact(
  contact: UnsavedContactEntry,
  jwtToken: string
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.post(apiName, `${resourcePath}`, {
      headers: {
        Authorization: `Bearer ${jwtToken}`,
      },
      body: contact,
    });
    return { data: data };
  } catch (error) {
    return {
      error: error as FetchBaseQueryError,
    };
  }
}

export async function editContact(
  contactId: string,
  contact: UnsavedContactEntry,
  jwtToken: string
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.put(apiName, `${resourcePath}?id=${contactId}`, {
      headers: {
        Authorization: `Bearer ${jwtToken}`,
      },
      body: contact,
    });
    return { data: data };
  } catch (error) {
    return {
      error: error as FetchBaseQueryError,
    };
  }
}

export async function deleteOneContact(
  contactId: string,
  jwtToken: string
): Promise<{ data: any } | { error: FetchBaseQueryError }> {
  try {
    const data = await API.del(apiName, `${resourcePath}?id=${contactId}`, {
      headers: {
        Authorization: `Bearer ${jwtToken}`,
      },
    });
    return { data: data };
  } catch (error) {
    return {
      error: error as FetchBaseQueryError,
    };
  }
}
