import { useParams } from "react-router-dom";

import Page from "components/Page";
import ContactForm from "./ContactForm";

import { useAppSelector } from "hooks/storeHooks";
import { useEditContactMutation, useGetContactByIdQuery } from "api/contacts";
import { skipToken } from "@reduxjs/toolkit/query";
import { SingeContactFormValues } from "types";

export default function EditContact() {
  const { id } = useParams();

  const [
    editContact,
    { data: editContactData, isLoading: EditIsLoading, isError },
  ] = useEditContactMutation();

  const jwtToken = useAppSelector(
    (state) => state.user.authUser.signInUserSession.idToken.jwtToken
  );

  const { data, isLoading } = useGetContactByIdQuery({
    contactId: id ?? skipToken,
    jwtToken: jwtToken,
  });

  if (isLoading) {
    return <>Loading</>;
  }

  if (!data) {
    return <>No Data</>;
  }

  const handleEdit = (value: SingeContactFormValues) => {
    console.log(data.id);
    console.log(value);
    editContact({ contactId: data.id, contact: value, jwtToken: jwtToken });
  };

  return (
    <Page title="Edit contact">
      <ContactForm
        title="Edit contact"
        onSubmit={handleEdit}
        value={{
          name: data.name,
          email: data.email,
          phoneNumber: data.phoneNumber,
          //labels: data?.,
          image: data?.image,
          /*             imageKey: data.imageKey, */
        }}
      />
    </Page>
  );
}
